==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Search/language/lang-brazilian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","Todos os Tpicos");
define("_NOCOMMENTS","Sem Comentrios");
define("_UCOMMENT","Comentrio");
define("_REVIEWS","Reviso");
define("_SEARCHUSERS","Buscar usurios no banco de dados");
define("_SEARCHSECTIONS","Buscar em Sees Especiais");
define("_SEARCHREVIEWS","Buscar em Revises");
define("_SEARCHIN","Buscar em");
define("_ARTICLES","Artigos");
define("_ALLAUTHORS","Todos os Autores");
define("_ALL","Todos");
define("_WEEK","semana");
define("_WEEKS","semanas");
define("_MONTH","ms");
define("_MONTHS","meses");
define("_SEARCHON","Buscar em:");
define("_SSTORIES","Histrias");
define("_SSECTIONS","Sees");
define("_SUSERS","Usurios");
define("_NOMATCHES","Nada encontrado para");
define("_PREVMATCHES","registros anteriores");
define("_NEXTMATCHES","prximos registros");
define("_INSECTION","Artigo na Seo");
define("_NONAME","Nenhum nome inscrito");
define("_SCOMMENTS","Comentrios");
define("_SEARCHRESULTS","Resultados da Busca");
define("_CONTRIBUTEDBY","Contribuio de");
define("_UCOMMENTS","Comentrios");
define("_MATCHTITLE","Igual ao Ttulo");
define("_MATCHTEXT","Igual ao Texto do Artigo");
define("_MATCHBOTH","Igual ao Ttulo e Texto do Artigo");
define("_SREPLY","Responder");
define("_SREPLIES","Responder");
define("_ATTACHART","Anexar ao Artigo");
define("_PAGES","Pginas");
define("_REVIEWSCORE","Pontuao para esta Reviso");
define("_PAGE","Pginas");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Search/language/lang-brazilian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","Todos os Tpicos");
define("_NOCOMMENTS","Sem Comentrios");
define("_UCOMMENT","Comentrio");
define("_REVIEWS","Reviso");
define("_SEARCHUSERS","Buscar usurios no banco de dados");
define("_SEARCHSECTIONS","Buscar em Sees Especiais");
define("_SEARCHREVIEWS","Buscar em Revises");
define("_SEARCHIN","Buscar em");
define("_ARTICLES","Artigos");
define("_ALLAUTHORS","Todos os Autores");
define("_ALL","Todos");
define("_WEEK","semana");
define("_WEEKS","semanas");
define("_MONTH","ms");
define("_MONTHS","meses");
define("_SEARCHON","Buscar em:");
define("_SSTORIES","Histrias");
define("_SSECTIONS","Sees");
define("_SUSERS","Usurios");
define("_NOMATCHES","Nada encontrado para");
define("_PREVMATCHES","registros anteriores");
define("_NEXTMATCHES","prximos registros");
define("_INSECTION","Artigo na Seo");
define("_NONAME","Nenhum nome inscrito");
define("_SCOMMENTS","Comentrios");
define("_SEARCHRESULTS","Resultados da Busca");
define("_CONTRIBUTEDBY","Contribuio de");
define("_UCOMMENTS","Comentrios");
define("_MATCHTITLE","Igual ao Ttulo");
define("_MATCHTEXT","Igual ao Texto do Artigo");
define("_MATCHBOTH","Igual ao Ttulo e Texto do Artigo");
define("_SREPLY","Responder");
define("_SREPLIES","Responder");
define("_ATTACHART","Anexar ao Artigo");
define("_PAGES","Pginas");
define("_REVIEWSCORE","Pontuao para esta Reviso");
define("_PAGE","Pginas");

?>
